View source: R/io_immundata_conversion.R
| from_immunarch | R Documentation |
The from_immunarch() function takes an immunarch object (as returned by
immunarch::repLoad()), writes each repertoire to a TSV file with an added
filename column in a specified folder, and then imports those files into
an ImmunData object via read_repertoires().
from_immunarch(
imm,
output_folder,
schema = c("CDR3.aa", "V.name"),
temp_folder = file.path(tempdir(), "temp_folder")
)
imm |
A list returned by
|
output_folder |
Path to the output directory where the resulting ImmunData Parquet files will be stored. This directory will be created if it does not already exist. |
schema |
Character vector of column names that together define unique
receptors (for example, |
temp_folder |
Path to a directory where intermediate TSV files will
be written. Defaults to |
An ImmunData object containing all repertoires from the input
immunarch object, with data saved under output_folder.
read_repertoires(), read_immundata(), ImmunData
## Not run:
imm <- immunarch::repLoad("/path/to/your/files")
idata <- from_immunarch(imm,
schema = c("CDR3.aa", "V.name"),
temp_folder = tempdir(),
output_folder = "/path/to/immundata_out"
)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.