View source: R/operations_utils.R
| make_receptor_schema | R Documentation |
Helper functions for defining and validating the schema used by
agg_receptors() to identify unique receptors.
make_receptor_schema() creates a schema list object.
assert_receptor_schema() checks if an object is a valid schema list and throws
an error if not.
test_receptor_schema() checks if an object is a valid schema list or a
character vector (which agg_receptors can also accept) and returns TRUE
or FALSE.
make_receptor_schema(features, chains = NULL)
assert_receptor_schema(schema)
test_receptor_schema(schema)
features |
Character vector. Column names defining the features of a single receptor chain (e.g., V gene, J gene, CDR3 sequence). |
chains |
Optional character vector (max length 2). Locus names (e.g.,
|
schema |
An object to test or assert as a valid schema. Can be a list
created by |
make_receptor_schema returns a list with elements features and chains.
assert_receptor_schema returns TRUE invisibly if valid, or stops execution.
test_receptor_schema returns TRUE or FALSE.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.