| make_seq_options | R Documentation |
Create sequence comparison options for the seq_options argument of
filter_immundata() or mutate_immundata(). Use these options to compare a
sequence column with one or more reference sequences or patterns.
make_seq_options(
query_col,
patterns,
method = c("exact", "lev", "hamm", "regex"),
max_dist = NA,
name_type = c("index", "pattern")
)
query_col |
Name of the sequence column to compare, such as |
patterns |
One or more reference sequences or regular-expression patterns. |
method |
Comparison method: |
max_dist |
Maximum distance accepted by |
name_type |
How result columns created by |
A named list for the seq_options argument of filter_immundata() or
mutate_immundata().
filter_immundata(), mutate_immundata(), annotate_receptors()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.