View source: R/io_manifest_read.R
| read_manifest | R Documentation |
This function loads a manifest from either a file path or a data frame, validates the presence of a column with repertoire file paths, and converts all file paths to absolute paths. It is used to support flexible pipelines for loading bulk or single-cell immune repertoire data across samples.
If the input is a file path, the function reads it with readr::read_delim.
If the input is a data frame, it checks whether file paths are absolute;
relative paths are only allowed when the manifest is loaded from a file.
It warns the user if many of the files listed in the manifest are missing, and stops execution if none of the files exist.
The column with file paths is normalized into the internal filename schema.
read_manifest(
manifest,
file_col = "file",
delim = NULL,
...,
verbose = getOption("immundata.verbose", TRUE)
)
manifest |
A manifest table. Can be either:
|
file_col |
A string specifying the name of the column in the manifest
that contains paths to repertoire files. Defaults to |
delim |
Delimiter used to read the manifest file. If |
... |
Additional arguments passed to |
verbose |
Logical(1). Whether to print informative messages. Defaults to
|
A validated and updated manifest data frame with absolute file paths
and an additional internal column named imd_filename.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.